@@ -22,7 +22,9 @@
 # Imports
 #
 from typing import Optional
+
 import pyrogram
+
 from telegram_payment_bot.utils.pyrogram_wrapper import PyrogramWrapper
 
 
@@ -51,7 +53,9 @@ class ChatHelper:
     @staticmethod
     def IsPrivateChat(chat: pyrogram.types.Chat,
                       user: pyrogram.types.User):
-        return not ChatHelper.IsChannel(chat) and chat.id == user.id
+        if ChatHelper.IsChannel(chat):
+            return False
+        return chat.id == user.id
 
 
 # Member helper class
@@ -60,6 +64,7 @@ class MemberHelper:
     @staticmethod
     def IsValidMember(member: pyrogram.types.ChatMember) -> bool:
         return (PyrogramWrapper.MemberIsStatus(member, "member") and
+                member.user is not None and
                 (member.user.is_self is None or not member.user.is_self) and
                 (member.user.is_bot is None or not member.user.is_bot))
 
@@ -86,4 +91,4 @@ class UserHelper:
 
         if user.first_name is not None:
             return f"{user.first_name} {user.last_name}" if user.last_name is not None else f"{user.first_name}"
-        return user.last_name
+        return user.last_name if user.last_name is not None else ""
